@@ -50,11 +50,7 @@ module Option = struct
     | None -> None
     | Some x -> Some (f x)
 
-  let some_if cond x =
-    if cond then
-      Some x
-    else
-      None
+  let some_if cond x = if cond then Some x else None
 
   let some x = Some x
 
@@ -87,7 +83,7 @@ module List = struct
     | x :: l -> (
       match f x with
       | None -> find_map l ~f
-      | Some _ as res -> res )
+      | Some _ as res -> res)
 end
 
 module Array = ArrayLabels
@@ -128,7 +124,7 @@ module Map (S : Map.OrderedType) = struct
       | (k, v) :: l -> (
         match find acc k with
         | None -> loop (set acc k v) l
-        | Some v_old -> Error (k, v_old, v) )
+        | Some v_old -> Error (k, v_old, v))
     in
     fun l -> loop empty l
 
@@ -185,10 +181,8 @@ module String = struct
     let rec loop ~last_is_cr ~acc i j =
       if j = length s then
         let acc =
-          if j = i || (j = i + 1 && last_is_cr) then
-            acc
-          else
-            sub s ~pos:i ~len:(j - i) :: acc
+          if j = i || (j = i + 1 && last_is_cr) then acc
+          else sub s ~pos:i ~len:(j - i) :: acc
         in
         List.rev acc
       else
@@ -196,12 +190,7 @@ module String = struct
         | '\r' -> loop ~last_is_cr:true ~acc i (j + 1)
         | '\n' ->
           let line =
-            let len =
-              if last_is_cr then
-                j - i - 1
-              else
-                j - i
-            in
+            let len = if last_is_cr then j - i - 1 else j - i in
             sub s ~pos:i ~len
           in
           loop ~acc:(line :: acc) (j + 1) (j + 1) ~last_is_cr:false
@@ -211,10 +200,7 @@ module String = struct
 
   let exists =
     let rec loop s i len f =
-      if i = len then
-        false
-      else
-        f (unsafe_get s i) || loop s (i + 1) len f
+      if i = len then false else f (unsafe_get s i) || loop s (i + 1) len f
     in
     fun s ~f -> loop s 0 (length s) f
 
@@ -224,62 +210,41 @@ module String = struct
 
   let extract_words s ~is_word_char =
     let rec skip_blanks i =
-      if i = length s then
-        []
-      else if is_word_char s.[i] then
-        parse_word i (i + 1)
-      else
-        skip_blanks (i + 1)
+      if i = length s then []
+      else if is_word_char s.[i] then parse_word i (i + 1)
+      else skip_blanks (i + 1)
     and parse_word i j =
-      if j = length s then
-        [ sub s ~pos:i ~len:(j - i) ]
-      else if is_word_char s.[j] then
-        parse_word i (j + 1)
-      else
-        sub s ~pos:i ~len:(j - i) :: skip_blanks (j + 1)
+      if j = length s then [ sub s ~pos:i ~len:(j - i) ]
+      else if is_word_char s.[j] then parse_word i (j + 1)
+      else sub s ~pos:i ~len:(j - i) :: skip_blanks (j + 1)
     in
     skip_blanks 0
 
   let extract_comma_space_separated_words s =
     extract_words s ~is_word_char:(function
-      | ','
-      | ' '
-      | '\t'
-      | '\n' ->
-        false
+      | ',' | ' ' | '\t' | '\n' -> false
       | _ -> true)
 
   let extract_blank_separated_words s =
     extract_words s ~is_word_char:(function
-      | ' '
-      | '\t' ->
-        false
+      | ' ' | '\t' -> false
       | _ -> true)
 
   let split s ~on =
     let rec loop i j =
-      if j = length s then
-        [ sub s ~pos:i ~len:(j - i) ]
-      else if s.[j] = on then
-        sub s ~pos:i ~len:(j - i) :: loop (j + 1) (j + 1)
-      else
-        loop i (j + 1)
+      if j = length s then [ sub s ~pos:i ~len:(j - i) ]
+      else if s.[j] = on then sub s ~pos:i ~len:(j - i) :: loop (j + 1) (j + 1)
+      else loop i (j + 1)
     in
     loop 0 0
 end
 
 module Io = struct
   let open_in ?(binary = true) fn =
-    if binary then
-      open_in_bin fn
-    else
-      open_in fn
+    if binary then open_in_bin fn else open_in fn
 
   let open_out ?(binary = true) fn =
-    if binary then
-      open_out_bin fn
-    else
-      open_out fn
+    if binary then open_out_bin fn else open_out fn
 
   let input_lines =
     let rec loop ic acc =
@@ -309,7 +274,8 @@ module Io = struct
   let read_all =
     (* We use 65536 because that is the size of OCaml's IO buffers. *)
     let chunk_size = 65536 in
-    (* Generic function for channels such that seeking is unsupported or broken *)
+    (* Generic function for channels such that seeking is unsupported or
+       broken *)
     let read_all_generic t buffer =
       let rec loop () =
         Buffer.add_channel buffer t chunk_size;
@@ -328,7 +294,8 @@ module Io = struct
         let s = really_input_string t n in
         (* For some files [in_channel_length] returns an invalid value. For
            instance for files in /proc it returns [0]. So we try to read one
-           more character to make sure we did indeed reach the end of the file *)
+           more character to make sure we did indeed reach the end of the
+           file *)
         match input_char t with
         | exception End_of_file -> s
         | c ->
@@ -338,7 +305,7 @@ module Io = struct
           let buffer = Buffer.create (String.length s + 1 + chunk_size) in
           Buffer.add_string buffer s;
           Buffer.add_char buffer c;
-          read_all_generic t buffer )
+          read_all_generic t buffer)
 
   let read_file ?binary fn = with_file_in fn ~f:read_all ?binary
 
